#
# spec file for package python3-pylint
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pylint
Version:        1.4.4
Release:        4.1
Summary:        Syntax and style checker for Python code
License:        GPL-2.0+
Group:          Development/Languages/Python
Url:            http://www.pylint.org/
Source:         https://pypi.python.org/packages/source/p/pylint/pylint-%{version}.tar.gz
BuildRequires:  python3-2to3
BuildRequires:  python3-astroid
BuildRequires:  python3-logilab-common >= 0.55
BuildRequires:  python3-tk
Requires:       python3-astroid
Requires:       python3-logilab-common >= 0.55
Requires:       python3-six
Requires:       python3-tk
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Pylint analyzes Python source code looking for bugs and signs of poor
quality.

Pylint is a python tool that checks if a module satisfies a coding
standard. Pylint can be seen as another PyChecker since nearly all
tests you can do with PyChecker can also be done with Pylint. But
Pylint offers some more features, like checking line-code's length,
checking if variable names are well-formed according to your coding
standard, or checking if declared interfaces are truly implemented, and
much more (see the complete check list).

The big advantage with Pylint is that it is highly configurable,
customizable, and you can easily write a small plugin to add a personal
feature.

%prep
%setup -q -n pylint-%{version}

%build
python3 setup.py build

%install
# build failes without --no-compile
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot} --no-compile
# fix non-executable rpmlint warning
chmod +x %{buildroot}%{python3_sitelib}/pylint/epylint.py
# update-alternatives
mv %{buildroot}%{_bindir}/pylint %{buildroot}%{_bindir}/pylint-%{py3_ver}
mv %{buildroot}%{_bindir}/epylint %{buildroot}%{_bindir}/epylint-%{py3_ver}
mv %{buildroot}%{_bindir}/pylint-gui %{buildroot}%{_bindir}/pylint-gui-%{py3_ver}
mv %{buildroot}%{_bindir}/pyreverse %{buildroot}%{_bindir}/pyreverse-%{py3_ver}
mv %{buildroot}%{_bindir}/symilar %{buildroot}%{_bindir}/symilar-%{py3_ver}
ln -s %{_bindir}/pylint-%{py3_ver} %{buildroot}%{_bindir}/pylint
ln -s %{_bindir}/epylint-%{py3_ver} %{buildroot}%{_bindir}/epylint
ln -s %{_bindir}/pylint-gui-%{py3_ver} %{buildroot}%{_bindir}/pylint-gui
ln -s %{_bindir}/pyreverse-%{py3_ver} %{buildroot}%{_bindir}/pyreverse
ln -s %{_bindir}/symilar-%{py3_ver} %{buildroot}%{_bindir}/symilar

%pre
# Since /usr/bin/pylint, etc. became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/pylint ] || rm -f %{_bindir}/pylint
[ -h %{_bindir}/epylint ] || rm -f %{_bindir}/epylint
[ -h %{_bindir}/pylint-gui ] || rm -f %{_bindir}/pylint-gui
[ -h %{_bindir}/pyreverse ] || rm -f %{_bindir}/pyreverse
[ -h %{_bindir}/symilar ] || rm -f %{_bindir}/symilar

%post
update-alternatives \
   --install %{_bindir}/pylint pylint %{_bindir}/pylint-%{py3_ver} 30 \
   --slave %{_bindir}/epylint epylint %{_bindir}/epylint-%{py3_ver} \
   --slave %{_bindir}/pylint-gui pylint-gui %{_bindir}/pylint-gui-%{py3_ver} \
   --slave %{_bindir}/pyreverse pyreverse %{_bindir}/pyreverse-%{py3_ver} \
   --slave %{_bindir}/symilar symilar %{_bindir}/symilar-%{py3_ver}

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pylint %{_bindir}/pylint-%{py3_ver}
fi

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README README.Python3 examples/
%{_bindir}/pylint-%{py3_ver}
%{_bindir}/epylint-%{py3_ver}
%{_bindir}/pylint-gui-%{py3_ver}
%{_bindir}/pyreverse-%{py3_ver}
%{_bindir}/symilar-%{py3_ver}
%ghost %{_bindir}/pylint
%ghost %{_bindir}/epylint
%ghost %{_bindir}/pylint-gui
%ghost %{_bindir}/pyreverse
%ghost %{_bindir}/symilar
%{python3_sitelib}/pylint/
%{python3_sitelib}/pylint-%{version}-py%{py3_ver}.egg-info

%changelog
* Tue Jun 30 2015 arun@gmx.de
- update to version 1.4.4:
  * Avoid breaking pylint when using logilab.common >= 1.0.
* Fri May 22 2015 tchvatal@suse.com
- Add  missing dependency over python3-six
* Sat Mar 14 2015 arun@gmx.de
- update to version 1.4.3:
  * Remove three warnings: star-args, abstract-class-little-used,
    abstract-class-not-used. These warnings don't add any real value
    and they don't imply errors or problems in the code.
  * Added a new option for controlling the peephole optimizer in
    astroid.  The option ``--optimize-ast`` will control the peephole
    optimizer, which is used to optimize a couple of AST subtrees. The
    current problem solved by the peephole optimizer is when multiple
    joined strings, with the addition operator, are encountered. If
    the numbers of such strings is high enough, Pylint will then fail
    with a maximum recursion depth exceeded error, due to its visitor
    architecture. The peephole just transforms such calls, if it can,
    into the final resulting string and this exhibit a problem,
    because the visit_binop method stops being called (in the
    optimized AST it will be a Const node).
* Wed Mar 11 2015 arun@gmx.de
- update to version 1.4.2:
  * Don't require a docstring for empty modules. Closes issue #261.
  * Fix a false positive with `too-few-format-args` string warning,
    emitted when the string format contained a normal positional
    argument ('{0}'), mixed with a positional argument which did an
    attribute access ('{0.__class__}').  Closes issue #463.
  * Take in account all the methods from the ancestors when checking
    for too-few-public-methods. Closes issue #471.
  * Catch enchant errors and emit 'invalid-characters-in-docstring'
    when checking for spelling errors. Closes issue #469.
  * Use all the inferred statements for the super-init-not-called
    check. Closes issue #389.
  * Add a new warning, 'unichr-builtin', emitted by the Python 3
    porting checker, when the unichr builtin is found. Closes issue
    [#472].
  * Add a new warning, 'intern-builtin', emitted by the Python 3
    porting checker, when the intern builtin is found. Closes issue
    [#473].
  * Add support for editable installations.
  * The HTML output accepts the `--msg-template` option. Patch by Dan
    Goldsmith.
  * Add 'map-builtin-not-iterating' (replacing
    'implicit-map-evaluation'), 'zip-builtin-not-iterating',
    'range-builtin-not-iterating', and 'filter-builtin-not-iterating'
    which are emitted by `--py3k` when the appropriate built-in is not
    used in an iterating context (semantics taken from 2to3).
  * Add a new warning, 'unidiomatic-typecheck', emitted when an
    explicit typecheck uses type() instead of isinstance(). For
    example, `type(x) == Y` instead of `isinstance(x, Y)`. Patch by
    Chris Rebert.  Closes issue #299.
  * Add support for combining the Python 3 checker mode with the
  - -jobs flag (--py3k and --jobs). Closes issue #467.
  * Add a new warning for the Python 3 porting checker,
    'using-cmp-argument', emitted when the `cmp` argument for the
    `list.sort` or `sorted builtin` is encountered.
  * Make the --py3k flag commutative with the -E flag. Also, this
    patch fixes the leaks of error messages from the Python 3 checker
    when the errors mode was activated. Closes issue #437.
* Sat Jan 17 2015 arun@gmx.de
- specfile: update copyright year
- update to version 1.4.1:
  * Look only in the current function's scope for bad-super-call.
    Closes issue #403.
  * Check the return of properties when checking for not-callable.
    Closes issue #406.
  * Warn about using the input() or round() built-ins for Python 3.
    Closes issue #411.
  * Proper abstract method lookup while checking for
    abstract-class-instantiated. Closes issue #401.
  * Use a mro traversal for finding abstract methods. Closes issue
    [#415].
  * Fix a false positive with catching-non-exception and tuples of
    exceptions.
  * Fix a false negative with raising-non-exception, when the raise
    used an uninferrable exception context.
  * Fix a false positive on Python 2 for raising-bad-type, when
    raising tuples in the form 'raise (ZeroDivisionError, None)'.
  * Fix a false positive with invalid-slots-objects, where the slot
    entry was an unicode string on Python 2. Closes issue #421.
  * Add a new warning, 'redundant-unittest-assert', emitted when using
    unittest's methods assertTrue and assertFalse with constant value
    as argument. Patch by Vlad Temian.
  * Add a new JSON reporter, usable through -f flag.
  * Add the method names for the 'signature-differs' and
    'argument-differs' warnings. Closes issue #433.
  * Don't compile test files when installing.
  * Fix a crash which occurred when using multiple jobs and the files
    given as argument didn't exist at all.
* Thu Dec 11 2014 arun@gmx.de
- specfile: update url to project homepage
- update to version: 1.4.0:
  * Added new options for controlling the loading of C extensions.
    By default, only C extensions from the stdlib will be loaded
    into the active Python interpreter for inspection, because they
    can run arbitrary code on import. The option
    `--extension-pkg-whitelist` can be used to specify modules
    or packages that are safe to load.
  * Change default max-line-length to 100 rather than 80
  * Drop BaseRawChecker class which were only there for backward
    compat for a while now
  * Don't try to analyze string formatting with objects coming from
    function arguments. Closes issue #373.
  * Port source code to be Python 2/3 compatible. This drops the
    need for 2to3, but does drop support for Python 2.5.
  * Each message now comes with a confidence level attached, and
    can be filtered base on this level. This allows to filter out
    all messages that were emitted even though an inference failure
    happened during checking.
  * Improved presenting unused-import message. Closes issue #293.
  * Add new checker for finding spelling errors. New messages:
    wrong-spelling-in-comment, wrong-spelling-in-docstring.
    New options: spelling-dict, spelling-ignore-words.
  * Add new '-j' option for running checks in sub-processes.
  * Added new checks for line endings if they are mixed (LF vs CRLF)
    or if they are not as expected. New messages: mixed-line-endings,
    unexpected-line-ending-format. New option: expected-line-ending-format.
  * 'dangerous-default-value' no longer evaluates the value of the arguments,
    which could result in long error messages or sensitive data being leaked.
    Closes issue #282
  * Fix a false positive with string formatting checker, when
    encountering a string which uses only position-based arguments.
    Closes issue #285.
  * Fix a false positive with string formatting checker, when using
    keyword argument packing. Closes issue #288.
  * Proper handle class level scope for lambdas.
  * Handle 'too-few-format-args' or 'too-many-format-args' for format
    strings with both named and positional fields. Closes issue #286.
  * Analyze only strings by the string format checker. Closes issue #287.
  * Properly handle nested format string fields. Closes issue #294.
  * Don't emit 'attribute-defined-outside-init' if the attribute
    was set by a function call in a defining method. Closes issue #192.
  * Properly handle unicode format strings for Python 2.
    Closes issue #296.
  * Don't emit 'import-error' if an import was protected by a try-except,
    which excepted ImportError.
  * Fix an 'unused-import' false positive, when the error was emitted
    for all the members imported with 'from import' form.
    Closes issue #304.
  * Don't emit 'invalid-name' when assigning a name in an
    ImportError handler. Closes issue #302.
  * Don't count branches from nested functions.
  * Fix a false positive with 'too-few-format-args', when the format
    strings contains duplicate manual position arguments.
    Closes issue #310.
  * fixme regex handles comments without spaces after the hash.
    Closes issue #311.
  * Don't emit 'unused-import' when a special object is imported
    (__all__, __doc__ etc.). Closes issue #309.
  * Look in the metaclass, if defined, for members not found in the current
    class. Closes issue #306.
  * Don't emit 'protected-access' if the attribute is accessed using
    a property defined at the class level.
  * Detect calls of the parent's __init__, through a binded super() call.
  * Check that a class has an explicitly defined metaclass before
    emitting 'old-style-class' for Python 2.
  * Emit 'catching-non-exception' for non-class nodes. Closes issue #303.
  * Order of reporting is consistent.
  * Add a new warning, 'boolean-datetime', emitted when an instance
    of 'datetime.time' is used in a boolean context. Closes issue #239.
  * Fix a crash which ocurred while checking for 'method-hidden',
    when the parent frame was something different than a function.
  * Generate html output for missing files. Closes issue #320.
  * Fix a false positive with 'too-many-format-args', when the format
    string contains mixed attribute access arguments and manual
    fields. Closes issue #322.
  * Extend the cases where 'undefined-variable' and 'used-before-assignment'
    can be detected. Closes issue #291.
  * Add support for customising callback identifiers, by adding a new
    '--callbacks' command line option. Closes issue #326.
  * Add a new warning, 'logging-format-interpolation', emitted when .format()
    string interpolation is used within logging function calls.
  * Don't emit 'unbalanced-tuple-unpacking' when the rhs of the assignment
    is a variable length argument. Closes issue #329.
  * Add a new warning, 'inherit-non-class', emitted when a class inherits
    from something which is not a class. Closes issue #331.
  * Fix another false positives with 'undefined-variable', where the variable
    can be found as a class assignment and used in a function annotation.
    Closes issue #342.
  * Handle assignment of the string format method to a variable.
    Closes issue #351.
  * Support wheel packaging format for PyPi. Closes issue #334.
  * Check that various built-ins that do not exist in Python 3 are not
    used: apply, basestring, buffer, cmp, coerce, execfile, file, long
    raw_input, reduce, StandardError, unicode, reload and xrange.
  * Warn for magic methods which are not used in any way in Python 3:
    __coerce__, __delslice__, __getslice__, __setslice__, __cmp__,
    __oct__, __nonzero__ and __hex__.
  * Don't emit 'assigning-non-slot' when the assignment is for a property.
    Closes issue #359.
  * Fix for regression: '{path}' was no longer accepted in '--msg-template'.
  * Report the percentage of all messages, not just for errors and warnings.
    Closes issue #319.
  * 'too-many-public-methods' is reported only for methods defined in a class,
    not in its ancestors. Closes issue #248.
  * 'too-many-lines' disable pragma can be located on any line, not only the
    first. Closes issue #321.
  * Warn in Python 2 when an import statement is found without a
    corresponding `from __future__ import absolute_import`.
  * Warn in Python 2 when a non-floor division operation is found without
    a corresponding `from __future__ import division`.
  * Add a new option, 'exclude-protected', for excluding members
    from the protected-access warning. Closes issue #48.
  * Warn in Python 2 when using dict.iter*(), dict.view*(); none of these
    methods are available in Python 3.
  * Warn in Python 2 when calling an object's next() method; Python 3 uses
    __next__() instead.
  * Warn when assigning to __metaclass__ at a class scope; in Python 3 a
    metaclass is specified as an argument to the 'class' statement.
  * Warn when performing parameter tuple unpacking; it is not supported in
    Python 3.
  * 'abstract-class-instantiated' is also emitted for Python 2.
    It was previously disabled.
  * Add 'long-suffix' error, emitted when encountering the long suffix
    on numbers.
  * Add support for disabling a checker, by specifying an 'enabled'
    attribute on the checker class.
  * Add a new CLI option, --py3k, for enabling Python 3 porting mode. This
    mode will disable all other checkers and will emit warnings and
    errors for constructs which are invalid or removed in Python 3.
  * Add 'old-octal-literal' to Python 3 porting checker, emitted when
    encountering octals with the old syntax.
  * Add 'implicit-map-evaluation' to Python 3 porting checker, emitted
    when encountering the use of map builtin, without explicit evaluation.
- changes form version 1.3.0:
  * Allow hanging continued indentation for implicitly concatenated
    strings. Closes issue #232.
  * Pylint works under Python 2.5 again, and its test suite passes.
  * Fix some false positives for the cellvar-from-loop warnings.
    Closes issue #233.
  * Return new astroid class nodes when the inferencer can detect that
    that result of a function invocation on a type (like `type` or
    `abc.ABCMeta`) is requested. Closes #205.
  * Emit 'undefined-variable' for undefined names when using the
    Python 3 `metaclass=` argument.
  * Checkers respect priority now. Close issue #229.
  * Fix a false positive regarding W0511. Closes issue #149.
  * Fix unused-import false positive with Python 3 metaclasses (#143).
  * Don't warn with 'bad-format-character' when encountering
    the 'a' format on Python 3.
  * Add multiple checks for PEP 3101 advanced string formatting:
  'bad-format-string', 'missing-format-argument-key',
  'unused-format-string-argument', 'format-combined-specification',
  'missing-format-attribute' and 'invalid-format-index'.
  * Issue broad-except and bare-except even if the number
    of except handlers is different than 1. Fixes issue #113.
  * Issue attribute-defined-outside-init for all cases, not just
    for the last assignment. Closes issue #262.
  * Emit 'not-callable' when calling properties. Closes issue #268.
  * Fix a false positive with unbalanced iterable unpacking,
    when encountering starred nodes. Closes issue #273.
  * Add new checks, 'invalid-slice-index' and 'invalid-sequence-index'
    for invalid sequence and slice indices.
  * Add 'assigning-non-slot' warning, which detects assignments to
    attributes not defined in slots.
  * Don't emit 'no-name-in-module' for ignored modules.
    Closes issue #223.
  * Fix an 'unused-variable' false positive, where the variable is
    assigned through an import. Closes issue #196.
  * Definition order is considered for classes, function arguments
    and annotations. Closes issue #257.
  * Don't emit 'unused-variable' when assigning to a nonlocal.
    Closes issue #275.
  * Do not let ImportError propagate from the import checker, leading to crash
    in some namespace package related cases. Closes issue #203.
  * Don't emit 'pointless-string-statement' for attribute docstrings.
    Closes issue #193.
  * Use the proper mode for pickle when opening and writing the stats file.
    Closes issue #148.
  * Don't emit hidden-method message when the attribute has been
    monkey-patched, you're on your own when you do that.
  * Only emit attribute-defined-outside-init for definition within the same
    module as the offended class, avoiding to mangle the output in some cases.
  * Don't emit 'unnecessary-lambda' if the body of the lambda call contains
    call chaining. Closes issue #243.
  * Don't emit 'missing-docstring' when the actual docstring uses `.format`.
    Closes issue #281.
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to version 1.2.1
  * Restore the ability to specify the init-hook option via the
    configuration file, which was accidentally broken in 1.2.0.
  * Add a new warning [bad-continuation] for badly indentend continued
    lines.
  * Emit [assignment-from-none] when the function contains bare returns.
    Fixes BitBucket issue #191.
  * Added a new warning for closing over variables that are
    defined in loops. Fixes Bitbucket issue #176.
  * Do not warn about \u escapes in string literals when Unicode literals
    are used for Python 2.*. Fixes BitBucket issue #151.
  * Extend the checking for unbalanced-tuple-unpacking and
    unpacking-non-sequence to instance attribute unpacking as well.
  * Fix explicit checking of python script (1.2 regression, #219)
  * Restore --init-hook, renamed accidentally into --init-hooks in 1.2.0
    (#211)
  * Add 'indexing-exception' warning, which detects that indexing
    an exception occurs in Python 2 (behaviour removed in Python 3).
- update to version 1.2.0
  * Pass the current python paths to pylint process when invoked via
    epylint.  Fixes BitBucket issue #133.
  * Add -i / --include-ids and -s / --symbols back as completely ignored
    options. Fixes BitBucket issue #180.
  * Extend the number of cases in which logging calls are detected. Fixes
    bitbucket issue #182.
  * Improve pragma handling to not detect pylint:* strings in non-comments.
    Fixes BitBucket issue #79.
  * Do not crash with UnknownMessage if an unknown message ID/name appears
    in disable or enable in the configuration. Patch by Cole Robinson.
    Fixes bitbucket issue #170.
  * Add new warning 'eval-used', checking that the builtin function `eval`
    was used.
  * Make it possible to show a naming hint for invalid name by setting
    include-naming-hint. Also make the naming hints configurable. Fixes
    BitBucket issue #138.
  * Added support for enforcing multiple, but consistent name styles for
    different name types inside a single module; based on a patch written
    by morbo@google.com.
  * Also warn about empty docstrings on overridden methods; contributed
    by sebastianu@google.com.
  * Also inspect arguments to constructor calls, and emit relevant
    warnings; contributed by sebastianu@google.com.
  * Added a new configuration option logging-modules to make the list
    of module names that can be checked for 'logging-not-lazy' et. al.
    configurable; contributed by morbo@google.com.
  * ensure init-hooks is evaluated before other options, notably load-plugins
    (#166)
  * Python 2.5 support restored: fixed small issues preventing pylint to run
    on python 2.5. Bitbucket issues #50 and #62.
  * bitbucket #128: pylint doesn't crash when looking
    for used-before-assignment in context manager
    assignments.
  * Add new warning, 'bad-reversed-sequence', for checking that the
    reversed() builtin receive a sequence (implements __getitem__ and __len__,
    without being a dict or a dict subclass) or an instance which implements
* Sun Feb 23 2014 arun@gmx.de
- update to version 1.1.0
  * Add new check for use of deprecated pragma directives "pylint:disable-msg"
    or "pylint:enable-msg" (I0022, deprecated-pragma) which was previously
    emmited as a regular warn().
  * Avoid false used-before-assignment for except handler defined
    identifier used on the same line (#111).
  * Combine 'no-space-after-operator', 'no-space-after-comma' and
    'no-space-before-operator' into a new warning 'bad-whitespace'.
  * Add a new warning 'superfluous-parens' for unnecessary
    parentheses after certain keywords.
  * Fix a potential crash in the redefine-in-handler warning
    if the redefined name is a nested getattr node.
  * Add a new option for the multi-statement warning to
    allow single-line if statements.
  * Add 'bad-context-manager' error, checking that '__exit__'
    special method accepts the right number of arguments.
  * Run pylint as a python module 'python -m pylint' (anatoly techtonik).
  * Check for non-exception classes inside an except clause.
  * epylint support options to give to pylint after the file to analyze and
    have basic input validation (bitbucket #53 and #54), patches provided by
    felipeochoa and Brian Lane.
  * Added a new warning, 'non-iterator-returned', for non-iterators
    returned by '__iter__'.
  * Add new checks for unpacking non-sequences in assignments
    (unpacking-non-sequence) as well as unbalanced tuple unpacking
    (unbalanced-tuple-unpacking).
  * useless-else-on-loop not emited if there is a break in the
    else clause of inner loop (#117).
  * don't mark `input` as a bad function when using python3 (#110).
  * badly-implemented-container caused several problems in its
    current implementation. Deactivate it until we have something
    better. See #112 for instance.
  * Use attribute regexp for properties in python3, as in python2
  * Create the PYLINTHOME directory when needed, it might fail and lead to
    spurious warnings on import of pylint.config.
  * Fix setup.py so that pylint properly install on Windows when using python3
  * Various documentation fixes and enhancements
  * Fix issue #55 (false-positive trailing-whitespace on Windows)
* Fri Nov 29 2013 toddrme2178@gmail.com
- Implement update-alternatives
- Update requires and buildrequires
- Update to version 1.0.0
  * Add check for the use of 'exec' function
  * New --msg-template option to control output, deprecating "msvc" and
    "parseable" output formats as well as killing `--include-ids` and `--symbols`
    options
  * Do not emit [fixme] for every line if the config value 'notes'
    is empty, but [fixme] is enabled.
  * Emit warnings about lines exceeding the column limit when
    those lines are inside multiline docstrings.
  * Do not double-check parameter names with the regex for parameters and
    inline variables.
  * Added a new warning missing-final-newline (C0304) for files missing
    the final newline.
  * Methods that are decorated as properties are now treated as attributes
    for the purposes of name checking.
  * Names of derived instance class member are not checked any more.
  * Names in global statements are now checked against the regular
    expression for constants.
  * For toplevel name assignment, the class name regex will be used if
    pylint can detect that value on the right-hand side is a class
    (like collections.namedtuple()).
  * Simplified invalid-name message
  * Added a new warning invalid-encoded-data (W0512) for files that
    contain data that cannot be decoded with the specified or
    default encoding.
  * New warning bad-open-mode (W1501) for calls to open (or file) that
    specify invalid open modes (Original implementation by Sasha Issayev).
  * New warning old-style-class (C1001) for classes that do not have any
    base class.
  * Add new name type 'class_attribute' for attributes defined
    in class scope. By default, allow both const and variable names.
  * New warning trailing-whitespace (C0303) that warns about
    trailing whitespace.
  * Added a new warning unpacking-in-except (W0712) about unpacking
    exceptions in handlers, which is unsupported in Python 3.
  * Add a configuration option for missing-docstring to
    optionally exempt short functions/methods/classes from
    the check.
  * Add the type of the offending node to missing-docstring
    and empty-docstring.
  * New utility classes for per-checker unittests in testutils.py
  * Do not warn about redefinitions of variables that match the
    dummy regex.
  * Do not treat all variables starting with _ as dummy variables,
    only _ itself.
  * Make the line-too-long warning configurable by adding a regex for lines
    for with the length limit should not be enforced
  * Do not warn about a long line if a pylint disable
    option brings it above the length limit
  * Do not flag names in nested with statements as undefined.
  * Added a new warning 'old-raise-syntax' for the deprecated syntax
    raise Exception, args
  * Support for PEP 3102 and new missing-kwoa (E1125) message for missing
    mandatory keyword argument (logilab.org's #107788)
  * Fix spelling of max-branchs option, now max-branches
  * Added a new base class and interface for checkers that work on the
    tokens rather than the syntax, and only tokenize the input file
    once.
  * Follow astng renaming to astroid
  * bitbucket #37: check for unbalanced unpacking in assignments
  * bitbucket #25: fix incomplete-protocol false positive for read-only
    containers like tuple
  * bitbucket #16: fix False positive E1003 on Python 3 for argument-less super()
  * bitbucket #6: put back documentation in source distribution
  * bitbucket #15: epylint shouldn't hang anymore when there is a large
    output on pylint'stderr
  * bitbucket #7: fix epylint w/ python3
  * bitbucket #3: remove string module from the default list of deprecated
    modules
- Remove unwanted %%{py_requires} macro
- Remove redundant %%clean section
* Thu Aug 15 2013 speilicke@suse.com
- Only buildrequire python3-2to3 on 12.2
* Mon Jul 15 2013 speilicke@suse.com
- Package COPYING
* Fri Jun 21 2013 speilicke@suse.com
- Use upstream URL
- Don't specically require python(abi)
- No need to provide/obsolete pylint, the py2 pkg does that already
- Drop outdated clean section
* Thu May 30 2013 dmueller@suse.com
- update to 0.28.0:
  * bitbucket #1: fix "dictionary changed size during iteration" crash
  * #74013: new E1310[bad-str-strip-call] message warning when a call to a
    {l,r,}strip method contains duplicate characters (patch by Torsten Marek)
  * #123233: new E0108[duplicate-argument-name] message reporting duplicate
    argument names
  * #81378: emit W0120[useless-else-on-loop] for loops without break
  * #124660: internal dependencies should not appear in external dependencies
    report
  * #124662: fix name error causing crash when symbols are included in output
    messages
  * #123285: apply pragmas for warnings attached to lines to physical source
    code lines
  * #123259: do not emit E0105 for yield expressions inside lambdas
  * #123892: don't crash when attempting to show source code line that can't
    be encoded with the current locale settings
  * Simplify checks for dangerous default values by unifying tests for all
    different mutable compound literals.
  * Improve the description for E1124[redundant-keyword-arg]
  * #20693: replace pylint.el by Ian Eure version (patch by J.Kotta)
  * #105327: add support for --disable=all option and deprecate the
    'disable-all' inline directive in favour of 'skip-file' (patch by
    A.Fayolle)
  * #110840: add messages I0020 and I0021 for reporting of suppressed
    messages and useless suppression pragmas. (patch by Torsten Marek)
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Fri May  4 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
- Added full url to source file
* Mon Apr 30 2012 toddrme2178@gmail.com
- Cleaned up spec file formatting
- Added python 3 package
